@@ -11,14 +11,12 @@ ahead = importr('ahead')
 
 class DynamicRegressor():
 
-    def __init__(self, h=5, level=95, 
-                 weights=[1/3, 1/3, 1/3], 
-                 pi="E", date_formatting="original"):
+    def __init__(self, h=5, level=95,                  
+                 type_pi="E", date_formatting="original"):
         
         self.h = h
         self.level = level
-        self.weights = weights
-        self.pi = pi
+        self.type_pi = type_pi
         self.date_formatting=date_formatting
 
         self.fcast = None
@@ -45,7 +43,7 @@ class DynamicRegressor():
 
         input_series = df.drop(columns=['date']).values
         y = stats.ts(FloatVector([item for sublist in input_series.tolist() for item in sublist]))
-        self.fcast = ahead.dynrmf(y, h=self.h, level=self.level, pi=self.pi)        
+        self.fcast = ahead.dynrmf(y, h=self.h, level=self.level, type_pi=self.type_pi)        
 
 
         # result -----
