@@ -13,14 +13,14 @@ class EAT():
 
     def __init__(self, h=5, level=95, 
                  weights=[1/3, 1/3, 1/3], 
-                 pi="E", date_formatting="original"):
+                 type_pi="E", date_formatting="original"):
 
         assert len(weights) == 3, "must have 'len(weights) == 3'"
         
         self.h = h
         self.level = level
         self.weights = weights
-        self.pi = pi
+        self.type_pi = type_pi
         self.date_formatting=date_formatting
 
         self.fcast = None
@@ -49,7 +49,7 @@ class EAT():
 
         input_series = df.drop(columns=['date']).values
         y = stats.ts(FloatVector([item for sublist in input_series.tolist() for item in sublist]))
-        self.fcast = ahead.eatf(y, h=self.h, level=self.level, pi=self.pi,
+        self.fcast = ahead.eatf(y, h=self.h, level=self.level, type_pi=self.type_pi,
                                 weights=FloatVector(self.weights))        
 
 
